Index: bp-core.php
===================================================================
--- bp-core.php	(revisione 1129)
+++ bp-core.php	(copia locale)
@@ -345,7 +345,7 @@
 	
 	if ( !$user_id ) return;
 	
-	$ud = get_userdata($user_id);
+	$ud = get_usermeta($user_id);
 	
 	return $bp->root_domain . '/' . MEMBERS_SLUG . '/' . $ud->user_login . '/';
 }
@@ -570,7 +570,7 @@
 	if ( $bp->current_component == MEMBERS_SLUG && isset( $_GET['random'] ) ) {
 		$user = BP_Core_User::get_random_users(1);
 
-		$ud = get_userdata( $user['users'][0]->user_id );
+		$ud = get_usermeta( $user['users'][0]->user_id );
 		bp_core_redirect( $bp->root_domain . '/' . MEMBERS_SLUG . '/' . $ud->user_login );
 	}
 }
@@ -618,7 +618,7 @@
  * @package BuddyPress Core
  * @param $uid int User ID to check.
  * @global $userdata WordPress user data for the current logged in user.
  * @uses get_userdata() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str the username of the matched user.
  */
@@ -628,7 +628,7 @@
 	if ( $uid == $userdata->ID )
 		return 'You';
 	
-	if ( !$ud = get_userdata($uid) )
+	if ( !$ud = get_usermeta($uid) )
 		return false;
 		
 	return $ud->user_login;	
@@ -642,7 +642,7 @@
  * @package BuddyPress Core
  * @param $uid int User ID to check.
  * @global $userdata WordPress user data for the current logged in user.
  * @uses get_userdata() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str The URL for the user with no HTML formatting.
  */
@@ -652,7 +652,7 @@
 	if ( !is_numeric($uid) )
 		return false;
 	
-	$ud = get_userdata($uid);
+	$ud = get_usermeta($uid);
 		
 	return $bp->root_domain . '/' . MEMBERS_SLUG . '/' . $ud->user_login . '/';
 }
@@ -664,12 +664,12 @@
  * 
  * @package BuddyPress Core
  * @param $uid int User ID to check.
  * @uses get_userdata() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str The email for the matched user.
  */
 function bp_core_get_user_email( $uid ) {
-	$ud = get_userdata($uid);
+	$ud = get_usermeta($uid);
 	return $ud->user_email;
 }
 
@@ -689,7 +689,7 @@
  * @param $just_link bool Disable full name and HTML and just return the URL text. Default false.
  * @param $no_you bool Disable replacing full name with "You" when logged in user is equal to the current user. Default false.
  * @global $userdata WordPress user data for the current logged in user.
  * @uses get_userdata() WordPress function to fetch the userdata for a user ID
  * @uses bp_fetch_user_fullname() Returns the full name for a user based on user ID.
  * @uses bp_core_get_userurl() Returns the URL for the user with no anchor tag based on user ID
  * @return false on no match
@@ -698,7 +698,7 @@
 function bp_core_get_userlink( $user_id, $no_anchor = false, $just_link = false, $deprecated = false, $with_s = false ) {
 	global $userdata;
 	
-	$ud = get_userdata($user_id);
+	$ud = get_usermeta($user_id);
 	
 	if ( !$ud )
 		return false;
@@ -737,14 +737,14 @@
  * @param $user_id string The user ID of the user.
  * @param
  * @uses bp_fetch_user_fullname() Returns the full name for a user based on user ID.
  * @uses get_userdata() Fetches a new userdata object for the user ID passed.
  * @return Either the users full name, or the display name.
  */
 function bp_core_global_user_fullname( $user_id ) {
 	if ( function_exists('bp_fetch_user_fullname') ) {
 		return bp_fetch_user_fullname( $user_id, false );
 	} else {
-		$ud = get_userdata($user_id);
+		$ud = get_usermeta($user_id);
 		return $current_user->display_name;
 	}
 }
@@ -789,7 +789,7 @@
  * 
  * @package BuddyPress Core
  * @param $uid int User ID to check.
  * @uses get_userdata() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str The email for the matched user.
  */
@@ -618,7 +618,7 @@
  * @param $uid int User ID to check.
  * @global $userdata WordPress user data for the current logged in user.
- * @uses get_userdata() WordPress function to fetch the userdata for a user ID
+ * @uses get_usermeta() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str the username of the matched user.
@@ -642,7 +642,7 @@
  * @param $uid int User ID to check.
  * @global $userdata WordPress user data for the current logged in user.
- * @uses get_userdata() WordPress function to fetch the userdata for a user ID
+ * @uses get_usermeta() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str The URL for the user with no HTML formatting.
@@ -664,12 +664,12 @@
  * @package BuddyPress Core
  * @param $uid int User ID to check.
- * @uses get_userdata() WordPress function to fetch the userdata for a user ID
+ * @uses get_usermeta() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str The email for the matched user.
@@ -689,7 +689,7 @@
  * @param $no_you bool Disable replacing full name with "You" when logged in user is equal to the current user. Default false.
  * @global $userdata WordPress user data for the current logged in user.
- * @uses get_userdata() WordPress function to fetch the userdata for a user ID
+ * @uses get_usermeta() WordPress function to fetch the userdata for a user ID
  * @uses bp_fetch_user_fullname() Returns the full name for a user based on user ID.
  * @uses bp_core_get_userurl() Returns the URL for the user with no anchor tag based on user ID
@@ -737,14 +737,14 @@
  * @param
  * @uses bp_fetch_user_fullname() Returns the full name for a user based on user ID.
- * @uses get_userdata() Fetches a new userdata object for the user ID passed.
+ * @uses get_usermeta() Fetches a new userdata object for the user ID passed.
  * @return Either the users full name, or the display name.
  */
@@ -789,7 +789,7 @@
  * @package BuddyPress Core
  * @param $uid int User ID to check.
- * @uses get_userdata() WordPress function to fetch the userdata for a user ID
+ * @uses get_usermeta() WordPress function to fetch the userdata for a user ID
  * @return false on no match
  * @return str The email for the matched user.
